Options class

Container that holds all available options for this program

Constructors

Options()

Properties

hashCode → int
The hash code for this object.
no setterinherited
options ↔ List<Option<String>>
The list of all available options
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOption<T>(String name) → Option<T>
Returns the option with the given name
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOption<T>(String name, T? value) → void
Sets the option with the given name to the given value
toString() → String
A string representation of this object.
override

Operators

operator +(Options other) → Options
When merging options we can use the + operator to merge the values
operator ==(Object other) → bool
The equality operator.
inherited