StringExtension extension

on

Properties

alphanumeric → String

Available on String, provided by the StringExtension extension

no setter
hasTokenReferences → bool

Available on String, provided by the StringExtension extension

no setter
isColorReference → bool

Available on String, provided by the StringExtension extension

no setter
isMathExpression → bool

Available on String, provided by the StringExtension extension

no setter
isTokenReference → bool

Available on String, provided by the StringExtension extension

Returns true if the string is a reference to another token path without any extras
no setter
valueByRef → String

Available on String, provided by the StringExtension extension

Returns the path of a reference, so we can search for the token
no setter