Generator class

Generates a Dart file with all the tokens.

Constructors

Generator(List<TokenTheme> themes)
Creates a new Generator instance.

Properties

extra → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
output → String
Returns the generated token themes code. (tokens.g.dart)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themes → List<TokenTheme>
The list of transformers to generate code for.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(String outputDirectory) → void
Saves the generated code to the given outputDirectory.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited