BorderValue class

Properties

color → ColorValue
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → BorderStyle
final
width → DimensionValue
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toStringForSide(BorderSide side) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

maybeParse(dynamic value) → BorderValue?