BoxShadowValueList class

Constructors

BoxShadowValueList(List<BoxShadowValue> shadows)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → List<BoxShadowValue>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

maybeParse(dynamic value) → BoxShadowValueList?