ColorValue class

Properties

a → int
final
b → int
final
g → int
final
hashCode → int
The hash code for this object.
no setterinherited
r → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

alphainate(double amount) → ColorValue
cascades this amount alpha on the existing alpha ignores any space info Should throw Exception for any value (1.0 < amount) or (amount < 0.0)
applyStudioExtension(dynamic extension) → ColorValue
darken(double amount) → ColorValue
declaration({bool isConst = true}) → String
lighten(double amount) → ColorValue
mix(String value, double amount) → ColorValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHex() → String
toHex8() → String
toHSL() → HSL
toRgb() → List<num>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

black → ColorValue
no setter

Static Methods

maybeParse(dynamic value) → ColorValue?