HSL class

Constructors

HSL(double h, double s, double l)

Properties

h → double
final
hashCode → int
The hash code for this object.
no setterinherited
l → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s → double
final

Methods

darken(double amount) → HSL
lighten(double amount) → HSL
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRGB() → List<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromRGB(double r, double g, double b) → HSL