DimensionValue class

A value that represents a dimension. This can be a number, a percentage, or a rem value. A percentage is converted to a decimal value between 0 and 1. A rem value is converted to a pixel value based on the base font size (see kBaseFontSize). Px values are converted to a double and returned as is. Last but not least, if the value is a number, it is converted to a double and returned as is. And if the value is not a number 0 is returned.

Implementers

Constructors

DimensionValue(double value)

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator *(num multiplicand) → DimensionValue
operator +(num addend) → DimensionValue
operator -(num difference) → DimensionValue
operator /(num divisor) → DimensionValue
operator ==(Object other) → bool
The equality operator.
override

Static Properties

zero → DimensionValue
no setter

Static Methods

maybeParse(dynamic value) → DimensionValue?