LetterSpacingValue class

A value that represents a letter spacing. This is different from DimensionValue because it can be a percentage. If it is a percentage, it is converted to a decimal value. This percentage is based on the base font size. 100% = 1rem = 16px. 50% = 0.5rem = 8px.

https://forum.figma.com/t/letter-spacing-should-not-be-percentage-based/3062/13

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator *(num multiplicand) → DimensionValue
inherited
operator +(num addend) → DimensionValue
inherited
operator -(num difference) → DimensionValue
inherited
operator /(num divisor) → DimensionValue
inherited
operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

maybeParse(dynamic value) → LetterSpacingValue?
Parses the given value to a LetterSpacingValue.
override