MultiDimensionValue class

A value that has multiple dimensions.

Constructors

MultiDimensionValue.parse(dynamic value)
Parses the given value to a MultiDimensionValue.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ List<DimensionValue>
The values of the dimensions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited