TokenTheme class

Constructors

TokenTheme(String name, List<String> sets)
TokenTheme.fromJson(Map<String, dynamic> e, List<String> allSets)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
resolvedTokens → List<Token>
Returns a list of all tokens that have been parsed and all references resolved.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sets → List<String>
final
tokens → Map<String, Token>
final
transformers → List<Transformer>
final

Methods

addTokens(Map<String, Token> tokens) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String key) → Token?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited