Processor class

Constructors

Processor({required List<TokenTheme> themes, List<TransformerFactory> singleTokenTransformerFactories = const [], List<TransformerFactory> multiTokenTransformerFactories = const []})

Properties

hashCode → int
The hash code for this object.
no setterinherited
multiTokenTransformerFactories → List<TransformerFactory>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleTokenTransformerFactories → List<TransformerFactory>
final
themes → List<TokenTheme>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited