BorderRadiusTransformer class

https://docs.tokens.studio/available-tokens/border-radius-tokens

Radius tokens give you the possibility to define values for your border radius. You can either create a single value token or define multiple border radii in a token.

Inheritance

Constructors

BorderRadiusTransformer()

Properties

className → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
lines → List<String>
finalinherited
name → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride

Methods

classDeclaration(String theme) → String
inherited
extraDeclaration() → String?
inherited
interfaceDeclaration() → String
inherited
matcher(Token token) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(Token token) → void
inherited
propertyDeclaration(String theme) → String
inherited
toString() → String
A string representation of this object.
inherited
transform(Token token) → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited