SingleTokenTransformer class abstract

Inheritance
Implementers

Constructors

SingleTokenTransformer()

Properties

className → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
lines → List<String>
finalinherited
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setter

Methods

classDeclaration(String theme) → String
inherited
extraDeclaration() → String?
inherited
interfaceDeclaration() → String
inherited
matcher(Token token) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(Token token) → void
override
propertyDeclaration(String theme) → String
inherited
toString() → String
A string representation of this object.
inherited
transform(Token token) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited