Transformer class abstract

A transformer is responsible for transforming a token into code that can be used in the generated code.

Implementers

Constructors

Transformer()

Properties

className → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
lines → List<String>
final
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

classDeclaration(String theme) → String
extraDeclaration() → String?
interfaceDeclaration() → String
matcher(Token token) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(Token token) → void
propertyDeclaration(String theme) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited